AgentAssistantResultEvent class

Assistant LLM response event.

Inheritance

Constructors

AgentAssistantResultEvent({required String prompt, required String response})
Creates a new AgentAssistantResultEvent.

Properties

hashCode int
The hash code for this object.
no setterinherited
prompt String
The user prompt or tool call result that prompted this response.
final
response String
The response from the LLM.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited