McpPlaygroundStorageDelegate class abstract

Abstract delegate for storing and loading LLM configuration, server registry, and saved setups.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadCachedServerTools(String serverId) Future<List<MCPTool>>
Loads cached tools list for a server ID.
loadEnabledTools() Future<Set<String>>
Loads the saved enabled tool names.
loadInitializedClients() Future<Set<String>>
Loads the set of initialized client IDs.
loadLlmConfig() Future<LlmConfig?>
Loads the saved LLM configuration.
loadServerCatalog() Future<String?>
Loads the saved server catalog response.
loadServerCatalogTimestamp() Future<int?>
Loads the saved server catalog timestamp.
loadServers() Future<List<McpServerConfig>>
Loads the list of registered MCP servers.
loadSetups() Future<List<SavedPlaygroundSetup>>
Loads the list of user-created configuration setups.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveCachedServerTools(String serverId, List<MCPTool> tools) Future<void>
Saves cached tools list for a server ID.
saveEnabledTools(Set<String> tools) Future<void>
Saves the active enabled tool names.
saveInitializedClients(Set<String> clients) Future<void>
Saves the set of initialized client IDs.
saveLlmConfig(LlmConfig config) Future<void>
Saves the active LLM configuration.
saveServerCatalog(String catalogJson) Future<void>
Saves the remote MCP server catalog response.
saveServerCatalogTimestamp(int timestamp) Future<void>
Saves the remote MCP server catalog timestamp.
saveServers(List<McpServerConfig> servers) Future<void>
Saves the list of registered MCP servers.
saveSetups(List<SavedPlaygroundSetup> setups) Future<void>
Saves the list of user-created configuration setups.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited