SharedPreferencesStorageDelegate class
A default implementation of McpPlaygroundStorageDelegate using SharedPreferences.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadCachedServerTools(
String serverId) → Future< List< MCPTool> > -
Loads cached tools list for a server ID.
override
-
loadEnabledTools(
) → Future< Set< String> > -
Loads the saved enabled tool names.
override
-
loadInitializedClients(
) → Future< Set< String> > -
Loads the set of initialized client IDs.
override
-
loadLlmConfig(
) → Future< LlmConfig?> -
Loads the saved LLM configuration.
override
-
loadServerCatalog(
) → Future< String?> -
Loads the saved server catalog response.
override
-
loadServerCatalogTimestamp(
) → Future< int?> -
Loads the saved server catalog timestamp.
override
-
loadServers(
) → Future< List< McpServerConfig> > -
Loads the list of registered MCP servers.
override
-
loadSetups(
) → Future< List< SavedPlaygroundSetup> > -
Loads the list of user-created configuration setups.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveCachedServerTools(
String serverId, List< MCPTool> tools) → Future<void> -
Saves cached tools list for a server ID.
override
-
saveEnabledTools(
Set< String> tools) → Future<void> -
Saves the active enabled tool names.
override
-
saveInitializedClients(
Set< String> clients) → Future<void> -
Saves the set of initialized client IDs.
override
-
saveLlmConfig(
LlmConfig config) → Future< void> -
Saves the active LLM configuration.
override
-
saveServerCatalog(
String catalogJson) → Future< void> -
Saves the remote MCP server catalog response.
override
-
saveServerCatalogTimestamp(
int timestamp) → Future< void> -
Saves the remote MCP server catalog timestamp.
override
-
saveServers(
List< McpServerConfig> servers) → Future<void> -
Saves the list of registered MCP servers.
override
-
saveSetups(
List< SavedPlaygroundSetup> setups) → Future<void> -
Saves the list of user-created configuration setups.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited